==> e107-0.7.20.tbz: www/e107/e107_plugins/rss_menu/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/rss_menu/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("RSS_LAN05","Number of items (0=inactive)");

define("RSS_MENU_L1", " can be syndicated by using these rss feeds.");
define("RSS_MENU_L2", "RSS Feeds");
define("RSS_MENU_L3", "Our news");
define("RSS_MENU_L4", "Our comments");
define("RSS_MENU_L5", "Our forum threads");
define("RSS_MENU_L6", "Our forum posts");
define("RSS_MENU_L7", "Our chatbox posts");
define("RSS_MENU_L8", "Our bugtracker reports");
define("RSS_MENU_L9", "Our downloads");

define("RSS_NEWS", "News");
define("RSS_COM", "Comments");
define("RSS_ART", "Articles");
define("RSS_REV", "Reviews");
define("RSS_FT", "Forum Threads");
define("RSS_FP", "Forum Posts");
define("RSS_FSP", "Forum Specific Post");
define("RSS_BUG", "Bugtracker");
define("RSS_FOR", "Forum");
define("RSS_DL", "Downloads");

define("RSS_PLUGIN_LAN_1", "RSS");

define("RSS_PLUGIN_LAN_6", "Feed Links");
define("RSS_PLUGIN_LAN_7", "The rss feed of the news");
define("RSS_PLUGIN_LAN_8", "The rss feed of the downloads");
define("RSS_PLUGIN_LAN_9", "The rss feed of the comments");
define("RSS_PLUGIN_LAN_10", "The rss feed of news category:");
define("RSS_PLUGIN_LAN_11", "The rss feed of download category:");

define("RSS_PLUGIN_LAN_14", "Comments");

define("RSS_LAN_ADMINMENU_1", "RSS Options");
define("RSS_LAN_ADMINMENU_2", "Listing");
define("RSS_LAN_ADMINMENU_4", "Import");

define("RSS_LAN_ERROR_1", "This is not a valid rss feed<br /><br /><a href='".e_SELF."'><< return to rss feed list</a>");
define("RSS_LAN_ERROR_2", "Your e107_config.php file or your language files contain spaces or ï»¿﻿ characters before the &lt;? characters. You should remove this with a non-utf8 text-editor if you wish to have a valid RSS feed.");
define("RSS_LAN_ERROR_3", "No rss feeds are present yet<br />please use the import feature to import available rss feeds or create a rss feed manually.");
define("RSS_LAN_ERROR_4", "No rss feeds are available yet");
define("RSS_LAN_ERROR_5", "This rss entry does not exist");
define("RSS_LAN_ERROR_6", "There are no rss feeds to import");
define("RSS_LAN_ERROR_7", "Some required fields are missing.");

define("RSS_LAN_ADMIN_1", "Existing RSS feeds");
define("RSS_LAN_ADMIN_2", "Id");
define("RSS_LAN_ADMIN_3", "Path");
define("RSS_LAN_ADMIN_4", "Name");
define("RSS_LAN_ADMIN_5", "Url");
define("RSS_LAN_ADMIN_6", "Text");
define("RSS_LAN_ADMIN_7", "Limit");
define("RSS_LAN_ADMIN_8", "Visibility");
define("RSS_LAN_ADMIN_9", "Type");
define("RSS_LAN_ADMIN_10", "rss feed create entry");
define("RSS_LAN_ADMIN_11", "rss feed import feeds");
define("RSS_LAN_ADMIN_12", "Topic id");

define("RSS_LAN_ADMIN_13", "Include Other-news items in News Feed?");
define("RSS_LAN_ADMIN_14", "Enable");
define("RSS_LAN_ADMIN_15", "Tick links to mark them for import ...");
define("RSS_LAN_ADMIN_16", "import?");
define("RSS_LAN_ADMIN_17", "import ticked links");
define("RSS_LAN_ADMIN_18", "rss feed(s) imported.");

define("RSS_LAN_ADMIN_21", "active and visible in rss feed list");
define("RSS_LAN_ADMIN_22", "active and not visible in rss feed list");
define("RSS_LAN_ADMIN_23", "inactive");

define("RSS_LAN_ADMIN_26", "Check All");
define("RSS_LAN_ADMIN_27", "Uncheck All");

define("RSS_LAN_ADMIN_31", "rss entries limit updated");

define("RSS_LAN_0", "RSS");
define("RSS_LAN_2", "@nospam.com");
define("RSS_LAN_3", "noauthor@nospam.com");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/rss_menu/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/rss_menu/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("RSS_LAN05","Number of items (0=inactive)");

define("RSS_MENU_L1", " can be syndicated by using these rss feeds.");
define("RSS_MENU_L2", "RSS Feeds");
define("RSS_MENU_L3", "Our news");
define("RSS_MENU_L4", "Our comments");
define("RSS_MENU_L5", "Our forum threads");
define("RSS_MENU_L6", "Our forum posts");
define("RSS_MENU_L7", "Our chatbox posts");
define("RSS_MENU_L8", "Our bugtracker reports");
define("RSS_MENU_L9", "Our downloads");

define("RSS_NEWS", "News");
define("RSS_COM", "Comments");
define("RSS_ART", "Articles");
define("RSS_REV", "Reviews");
define("RSS_FT", "Forum Threads");
define("RSS_FP", "Forum Posts");
define("RSS_FSP", "Forum Specific Post");
define("RSS_BUG", "Bugtracker");
define("RSS_FOR", "Forum");
define("RSS_DL", "Downloads");

define("RSS_PLUGIN_LAN_1", "RSS");

define("RSS_PLUGIN_LAN_6", "Feed Links");
define("RSS_PLUGIN_LAN_7", "The rss feed of the news");
define("RSS_PLUGIN_LAN_8", "The rss feed of the downloads");
define("RSS_PLUGIN_LAN_9", "The rss feed of the comments");
define("RSS_PLUGIN_LAN_10", "The rss feed of news category:");
define("RSS_PLUGIN_LAN_11", "The rss feed of download category:");

define("RSS_PLUGIN_LAN_14", "Comments");

define("RSS_LAN_ADMINMENU_1", "RSS Options");
define("RSS_LAN_ADMINMENU_2", "Listing");
define("RSS_LAN_ADMINMENU_4", "Import");

define("RSS_LAN_ERROR_1", "This is not a valid rss feed<br /><br /><a href='".e_SELF."'><< return to rss feed list</a>");
define("RSS_LAN_ERROR_2", "Your e107_config.php file or your language files contain spaces or ï»¿﻿ characters before the &lt;? characters. You should remove this with a non-utf8 text-editor if you wish to have a valid RSS feed.");
define("RSS_LAN_ERROR_3", "No rss feeds are present yet<br />please use the import feature to import available rss feeds or create a rss feed manually.");
define("RSS_LAN_ERROR_4", "No rss feeds are available yet");
define("RSS_LAN_ERROR_5", "This rss entry does not exist");
define("RSS_LAN_ERROR_6", "There are no rss feeds to import");
define("RSS_LAN_ERROR_7", "Some required fields are missing.");

define("RSS_LAN_ADMIN_1", "Existing RSS feeds");
define("RSS_LAN_ADMIN_2", "Id");
define("RSS_LAN_ADMIN_3", "Path");
define("RSS_LAN_ADMIN_4", "Name");
define("RSS_LAN_ADMIN_5", "Url");
define("RSS_LAN_ADMIN_6", "Text");
define("RSS_LAN_ADMIN_7", "Limit");
define("RSS_LAN_ADMIN_8", "Visibility");
define("RSS_LAN_ADMIN_9", "Type");
define("RSS_LAN_ADMIN_10", "rss feed create entry");
define("RSS_LAN_ADMIN_11", "rss feed import feeds");
define("RSS_LAN_ADMIN_12", "Topic id");

define("RSS_LAN_ADMIN_13", "Include Other-news items in News Feed?");
define("RSS_LAN_ADMIN_14", "Enable");
define("RSS_LAN_ADMIN_15", "Tick links to mark them for import ...");
define("RSS_LAN_ADMIN_16", "import?");
define("RSS_LAN_ADMIN_17", "import ticked links");
define("RSS_LAN_ADMIN_18", "rss feed(s) imported.");

define("RSS_LAN_ADMIN_21", "active and visible in rss feed list");
define("RSS_LAN_ADMIN_22", "active and not visible in rss feed list");
define("RSS_LAN_ADMIN_23", "inactive");

define("RSS_LAN_ADMIN_26", "Check All");
define("RSS_LAN_ADMIN_27", "Uncheck All");

define("RSS_LAN_ADMIN_31", "rss entries limit updated");

define("RSS_LAN_0", "RSS");
define("RSS_LAN_2", "@nospam.com");
define("RSS_LAN_3", "noauthor@nospam.com");

?>
